( cd usr/lib64 ; rm -rf libatk-1.0.so.0 )
( cd usr/lib64 ; ln -sf libatk-1.0.so.0.1010.3 libatk-1.0.so.0 )
( cd usr/lib64 ; rm -rf libatk-1.0.so )
( cd usr/lib64 ; ln -sf libatk-1.0.so.0.1010.3 libatk-1.0.so )
